@@ -1146,10 +1146,10 @@ class Project(ProjectPath):
         Returns:
             str: Output from the queuing system as string - optimized for the Sun grid engine
         """
-        if isinstance(item, int):
-            self.remove_job(job_specifier=item)
+        if not self.view_mode:
+            return queue_delete_job(item)
         else:
-            item.remove()
+            raise EnvironmentError("copy_to: is not available in Viewermode !")
 
     @staticmethod
     def create_hdf(path, job_name):
@@ -1207,15 +1207,15 @@ class Project(ProjectPath):
         return inputdict
 
     @staticmethod
-    def list_publications(bib_format="dict"):
+    def list_publications(bib_format="pandas"):
         """
         List the publications used in this project.
 
         Args:
-            bib_format (str): ['dict', 'bibtex', 'apa']
+            bib_format (str): ['pandas', 'dict', 'bibtex', 'apa']
 
         Returns:
-            list: list of publications in Bibtex format.
+            pandas.DataFrame/ list: list of publications in Bibtex format.
         """
         return list_publications(bib_format=bib_format)
 
@@ -1442,21 +1442,6 @@ class Project(ProjectPath):
         else:
             raise EnvironmentError("copy_to: is not available in Viewermode !")
 
-    def _queue_delete_job(self, item):
-        """
-        Delete a job from the queuing system
-
-        Args:
-            item (int, GenericJob): Provide either the job_ID or the full hamiltonian
-
-        Returns:
-            str: Output from the queuing system as string - optimized for the Sun grid engine
-        """
-        if not self.view_mode:
-            return queue_delete_job(item)
-        else:
-            raise EnvironmentError("copy_to: is not available in Viewermode !")
-
     def _update_jobs_in_old_database_format(self, job_name):
         """
 
